==> ejc-bfyjerp-impl-3.0.0-20250919.074230-294-sources.jar: com/ejianc/business/bid/controller/TenderFundsController.java <==
package com.ejianc.business.bid.controller;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.bid.bean.BusOpportunityEntity;
import com.ejianc.business.bid.bean.TenderFundsEntity;
import com.ejianc.business.bid.constants.BidCommonContants;
import com.ejianc.business.bid.service.IBusOpportunityService;
import com.ejianc.business.bid.service.ITenderFundsService;
import com.ejianc.business.bid.vo.TenderFundsVO;
import com.ejianc.business.finance.bean.PayRecordEntity;
import com.ejianc.business.finance.service.IPayRecordService;
import com.ejianc.business.finance.utils.WarnFeignUtil;
import com.ejianc.business.finance.vo.PayRecordVO;
import com.ejianc.foundation.message.api.IPushMessageApi;
import com.ejianc.foundation.orgcenter.api.IEmployeeApi;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.api.IUserApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.usercenter.vo.UserVO;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.*;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 投标管理-投标保证金
 *
 * @author generator
 *
 */
@RestController
@RequestMapping("tenderFunds")
public class TenderFundsController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;
    @Value("${common.env.base-host}")
    private String baseHost;
    @Autowired
    private WarnFeignUtil feignUtil;
    private static final String BILL_CODE = "BID_TENDER_FUNDS";
    @Autowired
    private IPayRecordService payRecordService;
    @Autowired
    private ITenderFundsService service;
    @Autowired
    private IUserApi userApi;

    @Autowired
    private SessionManager sessionManager;

    @Autowired
    private IBusOpportunityService busOpportunityService;

    @GetMapping(value = "getByBusOpportunityId")
    public CommonResponse<JSONObject> getByBusOpportunityId(@RequestParam Long id) {
        JSONObject resp = new JSONObject();
        List<TenderFundsVO> dataList = new ArrayList<>();
        List<TenderFundsEntity> list = service.getByBusOpportunityId(id);
        if(CollectionUtils.isNotEmpty(list)) {
            dataList = BeanMapper.mapList(list, TenderFundsVO.class);
        }
        resp.put("detailList", dataList);
        return CommonResponse.success(resp);
    }

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    public CommonResponse<TenderFundsVO> saveOrUpdate(@RequestBody TenderFundsVO saveOrUpdateVO) {
    	TenderFundsEntity entity = BeanMapper.map(saveOrUpdateVO, TenderFundsEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
            entity.setEmployeeId(Long.valueOf(InvocationInfoProxy.getEmployeeId()));
            entity.setEmployeeName(sessionManager.getUserContext().getEmployeeName());
            entity.setFundsBackId(Long.valueOf(BidCommonContants.STRING_NO)); //默认未被引用

            BusOpportunityEntity oppr = busOpportunityService.selectById(saveOrUpdateVO.getOpportunityId());
            entity.setRegistrationId(oppr.getRegistrationId());
            entity.setOpportunityBillCode(oppr.getBillCode());
            entity.setOrgId(oppr.getOrgId());
            entity.setOrgCode(oppr.getOrgCode());
            entity.setOrgName(oppr.getOrgName());
        }

    	service.saveOrUpdate(entity, false);

        if (null != entity.getAccountRegisterId()){
            service.sendMsgToDocumenter(entity);
        }
        //第二次保存给创建人发送消息
        if (null != saveOrUpdateVO.getId()) {
            List<String> pusherIds = new ArrayList<>();
            CommonResponse<UserVO> userVOCommonResponse = userApi.queryUserByUserCode(entity.getCreateUserCode());
            if (userVOCommonResponse.isSuccess()&&null !=userVOCommonResponse.getData()){
                pusherIds.add(userVOCommonResponse.getData().getId().toString());
            }
            //发送消息
            List<String> messageType = new ArrayList<>();
            messageType.add("sys");
            String formurl = baseHost + "ejc-bfyjerp-frontend/#/tenderFunds/card?id=" + saveOrUpdateVO.getId();
            if (CollectionUtils.isNotEmpty(pusherIds)) {
                StringBuffer buffer = new StringBuffer();
                buffer.append(saveOrUpdateVO.getEngineeringName() + "项目," + "保证金申请"+saveOrUpdateVO.getBoundsStatus()+"，请及时查看");
                String subject = buffer.toString();
                String content = subject + "<a href=" + '"' + formurl + '"' + ">前往点击</a>";
                feignUtil.sendMsg(messageType, pusherIds, "notice", subject, content, null);
            }
        }
        TenderFundsVO vo = BeanMapper.map(entity, TenderFundsVO.class);
        return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    public CommonResponse<TenderFundsVO> queryDetail(Long id) {
    	TenderFundsEntity entity = service.selectById(id);
    	TenderFundsVO vo = BeanMapper.map(entity, TenderFundsVO.class);
        LambdaQueryWrapper<PayRecordEntity> lambda = Wrappers.<PayRecordEntity>lambdaQuery();
        lambda.eq(PayRecordEntity::getPayapplyId, id);
        lambda.orderByDesc(PayRecordEntity::getCreateTime);
        List<PayRecordEntity> list = payRecordService.list(lambda);
        if(CollectionUtils.isNotEmpty(list)){
            vo.setPayRecordList(BeanMapper.mapList(list, PayRecordVO.class));
        }
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    public CommonResponse<String> delete(@RequestBody List<TenderFundsVO> vos) {
        service.removeByIds(vos.stream().map(TenderFundsVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    public CommonResponse<IPage<TenderFundsVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("engineeringName");
        fuzzyFields.add("recAccName");
        fuzzyFields.add("recAccBankName");
        fuzzyFields.add("recAcc");
        fuzzyFields.add("payAccName");
        fuzzyFields.add("payAcc");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        IPage<TenderFundsEntity> page = service.queryPage(param,false);
        IPage<TenderFundsVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), TenderFundsVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("engineeringName");
        fuzzyFields.add("recAccName");
        fuzzyFields.add("recAccBankName");
        fuzzyFields.add("recAcc");
        fuzzyFields.add("payAccName");
        fuzzyFields.add("payAcc");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<TenderFundsEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("TenderFunds-export.xlsx", beans, response);
    }

    @PostMapping(value = "changeBusinessStatus")
    public CommonResponse<String> changeBusinessStatus(@RequestBody Map<String, Object> params) {
        List<Long> ids = JSONArray.parseArray(params.get("ids").toString(), Long.class);
        String status = params.get("status").toString();
        service.changeBusinessStatus(ids, status);

        return CommonResponse.success("操作成功！");
    }

    /**
     * @param pageNumber
     * @param pageSize
     * @param condition
     * @param searchObject
     * @param searchText
     * @return
     */
    @RequestMapping(value = "/refTenderFundsData", method = RequestMethod.GET)
    public CommonResponse<IPage<TenderFundsVO>> refTenderFundsData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("engineeringName");
        fuzzyFields.add("recAccName");
        fuzzyFields.add("recAccBankName");
        fuzzyFields.add("recAcc");
        fuzzyFields.add("payAccName");
        fuzzyFields.add("payAcc");
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        param.getParams().put("fundsBackId", new Parameter(QueryParam.EQ, Long.valueOf(BidCommonContants.STRING_NO))); //查询未被引用的
        param.getParams().put("boundsStatus", new Parameter(QueryParam.EQ, TenderFundsVO.保证金状态_可退)); //查询可退的
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            JSONObject _con = JSONObject.parseObject(condition);
            if(_con.containsKey("opportunityId")) {
                param.getParams().put("opportunityId", new Parameter(QueryParam.EQ, _con.getLong("opportunityId")));
            }
            if (null != _con.get("selfFlag")){
                LambdaQueryWrapper<BusOpportunityEntity> opporqw = new LambdaQueryWrapper();
                opporqw.eq(BusOpportunityEntity::getCreateUserCode,InvocationInfoProxy.getUsercode());
                List<BusOpportunityEntity> opporList = busOpportunityService.list();
                List<Long> oppIds=new ArrayList<>();
                if (CollectionUtils.isNotEmpty(opporList)){
                     oppIds = opporList.stream().map(item -> item.getId()).collect(Collectors.toList());
                }
                ComplexParam c4 = new ComplexParam();
                c4.setLogic("and");
                ComplexParam c5 = new ComplexParam();
                c5.setLogic("or");
                c5.getParams().put("opportunityId", new Parameter(QueryParam.IN, oppIds));
                c4.getComplexParams().add(c5);
                ComplexParam c6 = new ComplexParam();
                c6.setLogic("or");
                c6.getParams().put("documenterId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getEmployeeId()));
                c4.getComplexParams().add(c6);
                param.getComplexParams().add(c4);
            }
        }

        //审批通过的
        param.getParams().put("billState", new Parameter(QueryParam.IN,
                Arrays.asList(new Integer[]{BillStateEnum.COMMITED_STATE.getBillStateCode(), BillStateEnum.PASSED_STATE.getBillStateCode()})));

        IPage<TenderFundsEntity> page = service.queryPage(param,false);
        IPage<TenderFundsVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), TenderFundsVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}

==> ejc-bfyjerp-impl-3.0.0-20251205.053804-310-sources.jar: com/ejianc/business/bid/controller/TenderFundsController.java <==
package com.ejianc.business.bid.controller;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.bid.bean.BusOpportunityEntity;
import com.ejianc.business.bid.bean.TenderFundsEntity;
import com.ejianc.business.bid.constants.BidCommonContants;
import com.ejianc.business.bid.service.IBusOpportunityService;
import com.ejianc.business.bid.service.ITenderFundsService;
import com.ejianc.business.bid.vo.TenderFundsVO;
import com.ejianc.business.finance.bean.PayRecordEntity;
import com.ejianc.business.finance.service.IPayRecordService;
import com.ejianc.business.finance.utils.WarnFeignUtil;
import com.ejianc.business.finance.vo.PayRecordVO;
import com.ejianc.foundation.message.api.IPushMessageApi;
import com.ejianc.foundation.orgcenter.api.IEmployeeApi;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.api.IUserApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.usercenter.vo.UserVO;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.*;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 投标管理-投标保证金
 *
 * @author generator
 *
 */
@RestController
@RequestMapping("tenderFunds")
public class TenderFundsController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;
    @Value("${common.env.base-host}")
    private String baseHost;
    @Autowired
    private WarnFeignUtil feignUtil;
    private static final String BILL_CODE = "BID_TENDER_FUNDS";
    @Autowired
    private IPayRecordService payRecordService;
    @Autowired
    private ITenderFundsService service;
    @Autowired
    private IUserApi userApi;

    @Autowired
    private SessionManager sessionManager;

    @Autowired
    private IBusOpportunityService busOpportunityService;

    @GetMapping(value = "getByBusOpportunityId")
    public CommonResponse<JSONObject> getByBusOpportunityId(@RequestParam Long id) {
        JSONObject resp = new JSONObject();
        List<TenderFundsVO> dataList = new ArrayList<>();
        List<TenderFundsEntity> list = service.getByBusOpportunityId(id);
        if(CollectionUtils.isNotEmpty(list)) {
            dataList = BeanMapper.mapList(list, TenderFundsVO.class);
        }
        resp.put("detailList", dataList);
        return CommonResponse.success(resp);
    }

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    public CommonResponse<TenderFundsVO> saveOrUpdate(@RequestBody TenderFundsVO saveOrUpdateVO) {
    	TenderFundsEntity entity = BeanMapper.map(saveOrUpdateVO, TenderFundsEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
            entity.setEmployeeId(Long.valueOf(InvocationInfoProxy.getEmployeeId()));
            entity.setEmployeeName(sessionManager.getUserContext().getEmployeeName());
            entity.setFundsBackId(Long.valueOf(BidCommonContants.STRING_NO)); //默认未被引用

            BusOpportunityEntity oppr = busOpportunityService.selectById(saveOrUpdateVO.getOpportunityId());
            entity.setRegistrationId(oppr.getRegistrationId());
            entity.setOpportunityBillCode(oppr.getBillCode());
            entity.setOrgId(oppr.getOrgId());
            entity.setOrgCode(oppr.getOrgCode());
            entity.setOrgName(oppr.getOrgName());
        }

    	service.saveOrUpdate(entity, false);

        if (null != entity.getAccountRegisterId()){
            service.sendMsgToDocumenter(entity);
        }
        //第二次保存给创建人发送消息
        if (null != saveOrUpdateVO.getId()) {
            List<String> pusherIds = new ArrayList<>();
            CommonResponse<UserVO> userVOCommonResponse = userApi.queryUserByUserCode(entity.getCreateUserCode());
            if (userVOCommonResponse.isSuccess()&&null !=userVOCommonResponse.getData()){
                pusherIds.add(userVOCommonResponse.getData().getId().toString());
            }
            //发送消息
            List<String> messageType = new ArrayList<>();
            messageType.add("sys");
            String formurl = baseHost + "ejc-bfyjerp-frontend/#/tenderFunds/card?id=" + saveOrUpdateVO.getId();
            if (CollectionUtils.isNotEmpty(pusherIds)) {
                StringBuffer buffer = new StringBuffer();
                buffer.append(saveOrUpdateVO.getEngineeringName() + "项目," + "保证金申请"+saveOrUpdateVO.getBoundsStatus()+"，请及时查看");
                String subject = buffer.toString();
                String content = subject + "<a href=" + '"' + formurl + '"' + ">前往点击</a>";
                feignUtil.sendMsg(messageType, pusherIds, "notice", subject, content, null);
            }
        }
        TenderFundsVO vo = BeanMapper.map(entity, TenderFundsVO.class);
        return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    public CommonResponse<TenderFundsVO> queryDetail(Long id) {
    	TenderFundsEntity entity = service.selectById(id);
    	TenderFundsVO vo = BeanMapper.map(entity, TenderFundsVO.class);
        LambdaQueryWrapper<PayRecordEntity> lambda = Wrappers.<PayRecordEntity>lambdaQuery();
        lambda.eq(PayRecordEntity::getPayapplyId, id);
        lambda.orderByDesc(PayRecordEntity::getCreateTime);
        List<PayRecordEntity> list = payRecordService.list(lambda);
        if(CollectionUtils.isNotEmpty(list)){
            vo.setPayRecordList(BeanMapper.mapList(list, PayRecordVO.class));
        }
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    public CommonResponse<String> delete(@RequestBody List<TenderFundsVO> vos) {
        service.removeByIds(vos.stream().map(TenderFundsVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    public CommonResponse<IPage<TenderFundsVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("engineeringName");
        fuzzyFields.add("recAccName");
        fuzzyFields.add("recAccBankName");
        fuzzyFields.add("recAcc");
        fuzzyFields.add("payAccName");
        fuzzyFields.add("payAcc");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = sessionManager.getUserContext().getAuthOrgIds();
        List<Long> orgIds = new ArrayList<>();
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgIds.addAll(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(","))
                    .map(Long::parseLong).collect(Collectors.toList())).getData().stream().map(OrgVO::getId).collect(Collectors.toList()));
        }else {//pc端查询
            //本下
            orgIds.addAll(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList()));
            //本上
            orgIds.addAll(iOrgApi.findParentsByOrgId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList()));
        }
        param.getParams().put("orgId",new Parameter(QueryParam.IN,orgIds));


        IPage<TenderFundsEntity> page = service.queryPage(param,false);
        IPage<TenderFundsVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), TenderFundsVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("engineeringName");
        fuzzyFields.add("recAccName");
        fuzzyFields.add("recAccBankName");
        fuzzyFields.add("recAcc");
        fuzzyFields.add("payAccName");
        fuzzyFields.add("payAcc");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = sessionManager.getUserContext().getAuthOrgIds();
        List<Long> orgIds = new ArrayList<>();
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgIds.addAll(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(","))
                    .map(Long::parseLong).collect(Collectors.toList())).getData().stream().map(OrgVO::getId).collect(Collectors.toList()));
        }else {//pc端查询
            //本下
            orgIds.addAll(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList()));
            //本上
            orgIds.addAll(iOrgApi.findParentsByOrgId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList()));
        }
        param.getParams().put("orgId",new Parameter(QueryParam.IN,orgIds));
        List<TenderFundsEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("TenderFunds-export.xlsx", beans, response);
    }

    @PostMapping(value = "changeBusinessStatus")
    public CommonResponse<String> changeBusinessStatus(@RequestBody Map<String, Object> params) {
        List<Long> ids = JSONArray.parseArray(params.get("ids").toString(), Long.class);
        String status = params.get("status").toString();
        service.changeBusinessStatus(ids, status);

        return CommonResponse.success("操作成功！");
    }

    /**
     * @param pageNumber
     * @param pageSize
     * @param condition
     * @param searchObject
     * @param searchText
     * @return
     */
    @RequestMapping(value = "/refTenderFundsData", method = RequestMethod.GET)
    public CommonResponse<IPage<TenderFundsVO>> refTenderFundsData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("engineeringName");
        fuzzyFields.add("recAccName");
        fuzzyFields.add("recAccBankName");
        fuzzyFields.add("recAcc");
        fuzzyFields.add("payAccName");
        fuzzyFields.add("payAcc");
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        param.getParams().put("fundsBackId", new Parameter(QueryParam.EQ, Long.valueOf(BidCommonContants.STRING_NO))); //查询未被引用的
        param.getParams().put("boundsStatus", new Parameter(QueryParam.EQ, TenderFundsVO.保证金状态_可退)); //查询可退的
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = sessionManager.getUserContext().getAuthOrgIds();
        List<Long> orgIds = new ArrayList<>();
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgIds.addAll(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(","))
                    .map(Long::parseLong).collect(Collectors.toList())).getData().stream().map(OrgVO::getId).collect(Collectors.toList()));
        }else {//pc端查询
            //本下
            orgIds.addAll(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList()));
            //本上
            orgIds.addAll(iOrgApi.findParentsByOrgId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList()));
        }
        param.getParams().put("orgId",new Parameter(QueryParam.IN,orgIds));

        if(StringUtils.isNotEmpty(condition)){
            JSONObject _con = JSONObject.parseObject(condition);
            if(_con.containsKey("opportunityId")) {
                param.getParams().put("opportunityId", new Parameter(QueryParam.EQ, _con.getLong("opportunityId")));
            }
            if (null != _con.get("selfFlag")){
                LambdaQueryWrapper<BusOpportunityEntity> opporqw = new LambdaQueryWrapper();
                opporqw.eq(BusOpportunityEntity::getCreateUserCode,InvocationInfoProxy.getUsercode());
                List<BusOpportunityEntity> opporList = busOpportunityService.list();
                List<Long> oppIds=new ArrayList<>();
                if (CollectionUtils.isNotEmpty(opporList)){
                     oppIds = opporList.stream().map(item -> item.getId()).collect(Collectors.toList());
                }
                ComplexParam c4 = new ComplexParam();
                c4.setLogic("and");
                ComplexParam c5 = new ComplexParam();
                c5.setLogic("or");
                c5.getParams().put("opportunityId", new Parameter(QueryParam.IN, oppIds));
                c4.getComplexParams().add(c5);
                ComplexParam c6 = new ComplexParam();
                c6.setLogic("or");
                c6.getParams().put("documenterId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getEmployeeId()));
                c4.getComplexParams().add(c6);
                param.getComplexParams().add(c4);
            }
        }

        //审批通过的
        param.getParams().put("billState", new Parameter(QueryParam.IN,
                Arrays.asList(new Integer[]{BillStateEnum.COMMITED_STATE.getBillStateCode(), BillStateEnum.PASSED_STATE.getBillStateCode()})));

        IPage<TenderFundsEntity> page = service.queryPage(param,false);
        IPage<TenderFundsVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), TenderFundsVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}
